aboutsummaryrefslogtreecommitdiffstats
path: root/src/colourramp.c
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/colourramp.c (renamed from src/colorramp.c)8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/colorramp.c b/src/colourramp.c
index ac197a1..1aa7f27 100644
--- a/src/colorramp.c
+++ b/src/colourramp.c
@@ -1,4 +1,4 @@
/* colorramp.c -- color temperature calculation source
* This file is part of redshift-ng.
*
* redshift-ng is free software: you can redistribute it and/or modify
@@ -56,9 +56,9 @@
}\
\
void\
- colorramp_fill_##SUFFIX(TYPE *gamma_r, TYPE *gamma_g, TYPE *gamma_b,\
- size_t size_r, size_t size_g, size_t size_b,\
- const struct color_setting *setting)\
+ colourramp_fill_##SUFFIX(TYPE *gamma_r, TYPE *gamma_g, TYPE *gamma_b,\
+ size_t size_r, size_t size_g, size_t size_b,\
+ const struct colour_setting *setting)\
{\
double r = 1, g = 1, b = 1;\
libred_get_colour(setting->temperature, &r, &g, &b);\
@@ -1,4 +1,4 @@
-/* colorramp.c -- color temperature calculation source
+/* colourramp.c -- colour temperature calculation source
* This file is part of redshift-ng.
*